@@ -1,17 +1,17 @@
 package Config::GitLike::Cascaded;
-use Any::Moose;
+use Moo;
 use Cwd;
 use File::Spec;
 
 extends 'Config::GitLike';
 
 has 'cascade' => (
-    default => 1,
+    default => sub { 1 },
     is => 'rw',
 );
 
 __PACKAGE__->meta->make_immutable;
-no Any::Moose;
+no Moo;
 
 1;
 
@@ -26,10 +26,11 @@ Config::GitLike::Cascaded - git-like config file parsing with cascaded inheritan
 This module exists purely for backwards compatibility; its use is
 deprecated, and will be removed in a future release.
 
-=head1 DESCRIPTION
+=head1 METHODS
 
-This module simply defaults L<Config::GitLike/cascaded> to a true
-value.
+=head2 cascade
+
+This module simply defaults L<Config::GitLike/cascade> to a true value.
 
 =head1 SEE ALSO
 
